@@ -1,4 +1,6 @@
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
+
 from django_future.models import ScheduledJob
 
 
@@ -24,6 +26,18 @@ class ScheduledJobAdmin(admin.ModelAdmin):
     list_display = ('time_slot_start', 'colorful_status', 'callable_name', 'args', 'kwargs', 'return_value')
     list_filter = ('status',)
     date_hierarchy = 'time_slot_start'
+    fieldsets = (
+        (None, {
+            'fields': ('status',)
+        }),
+        (_('Schedule'), {
+            'fields': ('time_slot_start', 'time_slot_end', 'execution_start')
+        }),
+        (_('Job'), {
+            'fields': ('callable_name', ('content_type', 'object_id'), 'error', 'return_value'),
+        }),
+    )
+
 
 # TODO: show (read-only) reprs of args and kwargs in job editor screen.
 
